
#line 2 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define __IDL_const const

#if defined(__GNUC__) && __GNUC__ >= 3
#define __IDL_noreturn __attribute__((__noreturn__))
#else
#define __IDL_noreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (__IDL__start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((__IDL__start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE __IDL_restart( __IDL_in  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(__IDL__state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct __IDL__buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t __IDL__size_t;
#endif

extern int __IDL_leng;

extern FILE *__IDL_in, *__IDL_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define __IDL_less(n) \
	do \
		{ \
		/* Undo effects of setting up __IDL_text. */ \
        int __IDL_less_macro_arg = (n); \
        YY_LESS_LINENO(__IDL_less_macro_arg);\
		*__IDL__cp = (__IDL__hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(__IDL__c_buf_p) = __IDL__cp = __IDL__bp + __IDL_less_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up __IDL_text again */ \
		} \
	while ( 0 )
#define unput(c) __IDL_unput( c, (__IDL_text_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct __IDL__buffer_state
	{
	FILE *__IDL__input_file;

	char *__IDL__ch_buf;		/* input buffer */
	char *__IDL__buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int __IDL__buf_size;

	/* Number of characters read into __IDL__ch_buf, not including EOB
	 * characters.
	 */
	int __IDL__n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int __IDL__is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int __IDL__is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int __IDL__at_bol;

    int __IDL__bs_lineno; /**< The line count. */
    int __IDL__bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int __IDL__fill_buffer;

	int __IDL__buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via __IDL_restart()), so that the user can continue scanning by
	 * just pointing __IDL_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t __IDL__buffer_stack_top = 0; /**< index of top of stack. */
static size_t __IDL__buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * __IDL__buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (__IDL__buffer_stack) \
                          ? (__IDL__buffer_stack)[(__IDL__buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (__IDL__buffer_stack)[(__IDL__buffer_stack_top)]

/* __IDL__hold_char holds the character lost when __IDL_text is formed. */
static char __IDL__hold_char;
static int __IDL__n_chars;		/* number of characters read into __IDL__ch_buf */
int __IDL_leng;

/* Points to current character in buffer. */
static char *__IDL__c_buf_p = NULL;
static int __IDL__init = 0;		/* whether we need to initialize */
static int __IDL__start = 0;	/* start state number */

/* Flag which is used to allow __IDL_wrap()'s to do buffer switches
 * instead of setting up a fresh __IDL_in.  A bit of a hack ...
 */
static int __IDL__did_buffer_switch_on_eof;

void __IDL_restart ( FILE *input_file  );
void __IDL__switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE __IDL__create_buffer ( FILE *file, int size  );
void __IDL__delete_buffer ( YY_BUFFER_STATE b  );
void __IDL__flush_buffer ( YY_BUFFER_STATE b  );
void __IDL_push_buffer_state ( YY_BUFFER_STATE new_buffer  );
void __IDL_pop_buffer_state ( void );

static void __IDL_ensure_buffer_stack ( void );
static void __IDL__load_buffer_state ( void );
static void __IDL__init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER __IDL__flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE __IDL__scan_buffer ( char *base, __IDL__size_t size  );
YY_BUFFER_STATE __IDL__scan_string ( const char *__IDL__str  );
YY_BUFFER_STATE __IDL__scan_bytes ( const char *bytes, int len  );

void *__IDL_alloc ( __IDL__size_t  );
void *__IDL_realloc ( void *, __IDL__size_t  );
void __IDL_free ( void *  );

#define __IDL__new_buffer __IDL__create_buffer
#define __IDL__set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        __IDL_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            __IDL__create_buffer( __IDL_in, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->__IDL__is_interactive = is_interactive; \
	}
#define __IDL__set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        __IDL_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            __IDL__create_buffer( __IDL_in, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->__IDL__at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->__IDL__at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *__IDL_in = NULL, *__IDL_out = NULL;

typedef int __IDL__state_type;

extern int __IDL_lineno;
int __IDL_lineno = 1;

extern char *__IDL_text;
#ifdef __IDL_text_ptr
#undef __IDL_text_ptr
#endif
#define __IDL_text_ptr __IDL_text

static __IDL__state_type __IDL__get_previous_state ( void );
static __IDL__state_type __IDL__try_NUL_trans ( __IDL__state_type current_state  );
static int __IDL__get_next_buffer ( void );
static void __IDL_noreturn __IDL__fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up __IDL_text.
 */
#define YY_DO_BEFORE_ACTION \
	(__IDL_text_ptr) = __IDL__bp; \
	__IDL_leng = (int) (__IDL__cp - __IDL__bp); \
	(__IDL__hold_char) = *__IDL__cp; \
	*__IDL__cp = '\0'; \
	(__IDL__c_buf_p) = __IDL__cp;
#define YY_NUM_RULES 69
#define YY_END_OF_BUFFER 70
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct __IDL__trans_info
	{
	flex_int32_t __IDL__verify;
	flex_int32_t __IDL__nxt;
	};
static const flex_int16_t __IDL__accept[376] =
    {   0,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        3,    3,   70,   68,    8,   65,   68,   68,   68,   68,
       68,    9,   10,   68,   68,   68,   56,   56,   56,   68,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,    8,    7,   68,
       68,   68,   60,   59,   68,    8,   65,   68,    8,    7,
        3,    3,    3,    3,    3,    3,    8,    0,   64,    0,
       63,    0,   13,   67,   66,   13,    9,   12,    0,    0,
       10,   52,   54,   53,   56,   58,   56,   56,   57,   57,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,

       56,   56,   29,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
        8,    7,    7,    7,    5,    7,    7,    1,    0,    0,
       60,    0,   62,    8,   67,   66,    8,    7,    7,    7,
        7,    5,    7,    7,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    2,    0,    0,    0,   66,
       13,    0,   13,   11,   56,   56,   57,   16,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   37,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,   56,    5,

        5,    7,    7,    1,   48,   61,   66,   62,    5,    5,
        5,    7,    7,    3,    3,    3,    3,    3,    2,    0,
        0,   13,   56,   15,   57,   56,   56,   19,   20,   56,
       56,   56,   56,   25,   56,   56,   56,   56,   56,   32,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   56,   49,   56,   56,    7,    7,    7,
        7,    3,    3,   14,   57,   56,   56,   21,   56,   56,
       56,   56,   27,   28,   30,   56,   56,   56,   35,   56,
       56,   56,   56,   41,   56,   56,   56,   56,   46,   56,
       50,   56,    7,    7,    7,    7,    3,    3,   57,   56,

       56,   56,   56,   24,   56,   56,   33,   34,   36,   38,
       56,   56,   42,   43,   44,   56,   56,   56,    7,    6,
        7,    7,    6,    7,    3,    3,    3,   57,   56,   18,
       22,   23,   56,   56,   56,   56,   45,   56,   51,    6,
        6,    4,    6,    6,    6,    4,    3,    3,    3,   57,
       56,   56,   56,   39,   40,   47,    4,    4,    4,    4,
        4,    3,    3,   57,   17,   26,   31,   57,    0,    0,
        0,   55,    0,    0,    0
    } ;

static const YY_CHAR __IDL__ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    6,    1,    7,    8,
        9,   10,    1,    1,   11,   12,   13,   14,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   16,    1,   17,
        1,   18,    1,    1,   19,   20,   20,   21,   22,   23,
       24,   24,   24,   24,   24,   25,   24,   24,   24,   24,
       24,   26,   27,   28,   29,   24,   24,   30,   24,   24,
        1,    1,   31,    1,   32,    1,   33,   34,   35,   36,

       37,   38,   39,   40,   41,   24,   24,   42,   43,   44,
       45,   46,   47,   48,   49,   50,   51,   52,   53,   54,
       55,   24,   56,    1,   57,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR __IDL__meta[58] =
    {   0,
        1,    2,    3,    1,    1,    1,    1,    1,    4,    1,
        1,    1,    1,    5,    5,    1,    1,    1,    6,    6,
        6,    6,    6,    7,    7,    7,    7,    7,    7,    7,
        1,    8,    6,    6,    6,    6,    6,    6,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    1,    1
    } ;

static const flex_int16_t __IDL__base[407] =
    {   0,
        0,   56, 1008,   58,   70,  127,   87,   90,    0,   63,
       95,  104, 1019, 1021, 1016, 1021,   63,  108,   90,   98,
       81,  173,  134, 1001,  999,  997,  982,  128,   88,  981,
      118,  119,  121,  120,  135,  131,  137,  145,  146,   86,
      161,  143,  167,  142,  154,  168,  176,  119,  200,  956,
      204,    0,    0, 1021, 1002,  114, 1001,  213,  219,  229,
        0, 1007,  112,  228,  234,  951, 1005,  231, 1021,  234,
     1021,  238,  241, 1021,    0,  246,  272, 1021,  243,    0,
      276, 1021, 1021, 1021,  974,    0,  215,  237,    0,  969,
      174,  249,  219,  240,  263,  241,  207,  150,  260,  268,

      247,  270,  272,  274,  278,  273,  275,  233,  284,  287,
      288,  292,  295,  294,  297,  298,  300,  304,  303,  301,
      345,  344,    0,  346,  338,  963,  955,    0,  990,  992,
        0,  991, 1021,  353,  990,  328,  361,  362,  364,  366,
        0,  369,  376,  379,    0,  996,    0,    0,  352,  387,
        0,  385,  379,  956,  948,    0,  382,  399,  395,    0,
      401,  410,  425,    0,  394,  373,  958,  962,  359,  400,
      404,  396,  398,  413,  417,  411,  418,  420,  426,  402,
      424,  428,  430,  431,  432,  366,  961,  433,  434,  436,
      441,  439,  324,  442,  443,  444,  459,  445,  451,    0,

      478,  948,  958,    0, 1021, 1021,  491,    0,  493,    0,
      494,  495,  498,    0,    0,  491,  946,  956,    0,  496,
      498,  500,  494,  956,  952,  486,  487,  954,  953,  488,
      491,  489,  493,  952,  490,  497,  498,  502,  505,  951,
      509,  510,  511,  512,  517,  514,  518,  515,  524,  525,
      531,  535,  526,  537,  950,  532,  540,  944,  941,  570,
      574,  942,  939,  945,  934,  452,  542,  943,  546,  550,
      552,  553,  942,  941,  940,  555,  554,  558,  937,  556,
      565,  562,  564,  928,  566,  567,  569,  578,  912,  572,
      904,  580,  616,  877,  618,  616,  620,  869,  855,  591,

      594,  596,  597,  864,  604,  607,  840,  832,  818,  810,
      609,  617,  802,  775,  766,  605,  616,  618,  652,  641,
      713,  659,  655,  662,  661,  663,  712,  698,  640,  711,
      710,  706,  647,  648,  649,  650,  704,  652,  702,    0,
      671,  724,  688,    0,  691,  699,    0,  684,  721,  676,
      675,  671,  677,  679,  664,  661,    0,  687,  707,  715,
        0,    0,  658,  609,  570,  160,   27,  717,  719,  726,
      728, 1021,  730,  738, 1021,  747,  755,  763,  771,  779,
      783,  787,  795,  803,  807,  815,  823,  831,  839,  847,
      851,  853,  861,  869,  877,  885,  893,  901,  909,  917,

      925,  933,  941,  949,  957,  964
    } ;

static const flex_int16_t __IDL__def[407] =
    {   0,
      375,    1,    1,    1,  376,  376,  377,  377,    1,    1,
      378,  378,  375,  375,  375,  375,  379,  380,  375,  375,
      375,  375,  375,  375,  375,  375,  381,  381,  381,  382,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  375,  383,  375,
      375,  384,  385,  375,  386,  386,  386,  386,  386,  387,
      388,  388,  388,  388,  389,  388,  375,  379,  375,  380,
      375,  375,  375,  375,  390,  375,  375,  375,  375,  391,
      375,  375,  375,  375,  381,  392,  381,  381,  382,  382,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,

      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      375,  383,  383,  383,  393,  383,  383,  394,  375,  384,
      385,  386,  375,  386,  386,  395,  386,  387,  387,  387,
      383,  396,  387,  387,  388,  388,  388,  397,  388,  389,
      389,  389,  398,  389,  389,  399,  375,  375,  375,  390,
      375,  375,  375,  391,  381,  381,  382,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  393,

      393,  383,  383,  394,  375,  375,  395,  390,  396,  393,
      396,  387,  387,  397,  398,  398,  389,  389,  399,  375,
      375,  375,  381,  381,  382,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  383,  383,  387,
      387,  389,  389,  381,  382,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  383,  383,  387,  387,  389,  389,  382,  381,

      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  383,  400,
      383,  387,  401,  387,  389,  402,  389,  382,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  400,
      400,  403,  401,  400,  401,  404,  402,  402,  405,  382,
      381,  381,  381,  381,  381,  381,  403,  403,  404,  404,
      403,  405,  405,  382,  381,  381,  381,  382,  375,  406,
      406,  375,  406,  375,    0,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,

      375,  375,  375,  375,  375,  375
    } ;

static const flex_int16_t __IDL__nxt[1079] =
    {   0,
       14,   15,   16,   17,   14,   14,   18,   14,   14,   14,
       19,   20,   21,   22,   23,   24,   25,   26,   27,   27,
       27,   27,   28,   27,   27,   27,   27,   29,   27,   27,
       14,   30,   31,   32,   33,   34,   35,   36,   27,   27,
       37,   38,   39,   40,   41,   27,   27,   42,   43,   44,
       45,   46,   47,   27,   27,   14,   14,   48,   86,   48,
       49,   50,   49,   50,   48,   69,   69,   49,   50,   51,
       14,   15,   16,   14,   14,   14,   14,   52,   14,   14,
       14,   14,   21,   14,   14,   14,   14,   14,   56,   57,
       74,   59,   57,   75,   60,   14,   62,   16,   14,   58,

       54,   14,   58,   72,   72,   64,   16,   63,   65,   66,
       71,   73,   73,   88,   71,  134,   63,   86,  106,   86,
      121,  147,  133,  122,  148,   14,   14,   14,   48,   16,
       14,   49,   14,   14,   52,   14,   14,   14,   14,   21,
       14,   14,   14,   14,   14,   76,   87,   81,   81,   86,
       86,   86,   86,   94,   78,   79,   97,   54,   14,   86,
       95,   91,   86,   93,   98,   96,   86,   92,   86,   78,
       79,  101,  102,   86,   86,  110,   86,   86,   99,  111,
      103,   86,   14,   14,   76,   86,   77,   77,  100,  104,
      105,   86,   86,   78,   79,  107,  116,  117,   86,   86,

      175,  124,   80,  112,  108,   86,  113,   86,   78,   79,
      119,  109,  118,  125,  125,  129,  114,   73,   73,  115,
      137,  133,  135,  138,  120,  136,   80,  133,  168,  149,
      140,  132,  150,   69,   69,  152,   71,  141,   86,  165,
       71,  126,  142,  142,  174,  127,   86,  153,  153,  157,
       86,  158,  158,  162,   73,   73,  163,  163,   78,  161,
      161,   78,  159,  170,   86,  166,   78,   79,   86,  186,
      143,   86,   86,   78,  144,  154,   78,  159,   86,  155,
       86,   78,   79,   76,  173,   77,   77,   76,  171,   81,
       81,   86,   78,   79,   86,  172,   78,   79,  169,   86,

      178,   86,  177,   86,   86,   86,   86,   78,   79,   86,
      176,   78,   79,  183,  179,   86,  180,  182,   86,   86,
      189,  181,  184,   86,  185,   86,   86,  188,   86,   86,
      132,   86,   86,  187,   86,   86,  208,  193,  190,  191,
      195,  192,  198,  194,  197,  124,  121,  124,  196,  122,
      199,  201,  201,  149,  134,   86,  150,  125,  125,  125,
      125,  133,  137,  140,  132,  138,  132,  140,  132,  133,
      141,  132,  141,  251,  141,  142,  142,  210,  132,  142,
      142,  132,  211,  211,  141,  126,  152,  141,  152,  127,
       86,  127,  216,  216,  224,  220,  220,   86,  153,  153,

      153,  153,   78,  143,   86,  221,  226,  144,  222,  222,
      157,  144,  158,  158,  161,  161,  212,   78,  244,   78,
      223,   78,  159,  163,  163,   86,  213,   86,  154,   86,
      155,   86,  155,   86,   78,   86,   78,  159,  163,  163,
      228,  227,   86,  229,   86,  232,  230,  231,   86,   86,
      233,   86,  238,  234,  235,   86,  236,   86,  237,   86,
      239,   86,   86,   86,   86,   86,  240,   86,  243,  246,
       86,  242,   86,   86,   86,   86,   86,  256,  252,  249,
      241,  245,   86,   86,  254,  300,  247,  253,  248,  250,
       86,  201,  201,  132,  255,  132,  132,  132,  257,  208,

      132,  210,  210,  141,  216,  216,  141,  211,  211,  220,
      220,  222,  222,  222,  222,  264,   78,   86,   86,   86,
       86,   86,   86,  267,   86,   86,  266,  269,   86,   86,
      261,   78,  273,   86,  271,  272,   86,  268,  260,  270,
       86,   86,   86,   86,  280,   86,   86,  274,   86,   86,
      277,  275,  276,  281,  283,   86,   86,   86,  282,  286,
      279,  278,   86,   86,  284,  287,   86,  285,   86,  289,
      288,   86,  132,   86,  301,  290,  132,   86,  141,  291,
      292,   86,  141,   86,   86,   86,   86,   86,  304,   86,
      307,  303,  306,   86,  308,   86,   86,   86,   86,  302,

       86,   86,  305,   86,  313,  311,  295,  312,  315,   86,
      309,   86,  296,  310,  316,  317,  314,  319,  132,  322,
      132,  325,   86,  318,  141,   86,  141,   86,   86,  320,
      320,  323,  323,  326,  326,   86,   86,  330,   86,  334,
       86,  329,  337,  368,  333,  331,  332,   86,   86,   86,
      335,  336,  338,  319,  341,  341,  339,  132,  324,  363,
      322,  132,  325,  344,  132,  320,  320,  141,  345,  345,
      141,   86,  323,  323,  326,  326,  348,  348,   86,   86,
       86,   86,  353,   86,  341,  341,  355,  356,  358,  351,
      132,  352,   86,  132,  346,   86,  344,  348,  348,  344,

      360,  132,   86,  354,  345,  345,   86,  361,   86,  132,
       86,  365,  364,  367,  366,  361,  360,  132,  369,  369,
      369,  369,  363,  361,  370,  358,  370,  371,  371,  371,
      371,  374,  374,   86,  372,   86,  372,   86,  372,  374,
      374,   86,   86,  350,  349,  342,  372,   53,   53,   53,
       53,   53,   53,   53,   53,   55,   55,   55,   55,   55,
       55,   55,   55,   61,   61,   61,   61,   61,   61,   61,
       61,   68,   68,   68,   68,   68,   68,   68,   68,   70,
       70,   70,   70,   70,   70,   70,   70,   85,   85,   85,
       85,   89,   89,   89,   89,  123,  123,   86,  123,  123,

      123,  123,  123,  130,  130,  130,   86,  130,  130,  130,
      130,  131,  131,  131,  131,  132,  132,  132,  132,  132,
      132,  132,  132,  139,  139,  139,  139,  139,  139,  139,
      139,  145,  145,   86,  145,  145,  145,  145,  145,  151,
      151,   86,  151,  151,  151,  151,  151,  160,  160,   86,
      160,  160,  160,  160,  160,  164,  164,   86,   86,   86,
       86,  200,  200,   86,  200,  200,  200,  200,  200,  204,
      204,   86,  204,  204,  204,  204,  204,  207,  207,  207,
      207,  207,  207,  207,  207,  209,  209,  209,  209,  209,
      209,  209,  209,  214,  214,   86,  214,  214,  214,  214,

      214,  215,  215,  328,  215,  215,  215,  215,  215,  219,
      219,  327,  219,  219,  219,  219,  219,  340,  340,  321,
      340,  340,  340,  340,  340,  343,  343,  343,  343,  343,
      343,  343,  343,  347,  347,   86,  347,  347,  347,  347,
      347,  357,  357,   86,  357,  357,  357,  357,  357,  359,
      359,  359,  359,  359,  359,  359,  359,  362,  362,   86,
      362,  362,  362,  362,  362,  373,  373,  373,   86,  373,
      373,   86,   86,   86,   86,  299,   86,  298,  297,  294,
      293,   86,   86,   86,   86,   86,  265,   86,  263,  262,
      259,  258,   86,   86,  225,  218,  217,  146,  133,  133,

      206,  205,  203,  202,  167,   86,   67,  156,  146,  133,
      133,  128,   90,   86,   84,   83,   82,   67,  375,   51,
       13,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375
    } ;

static const flex_int16_t __IDL__chk[1079] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    2,  367,    4,
        2,    2,    4,    4,   10,   17,   17,   10,   10,    4,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    7,    7,
       21,    8,    8,   21,    8,    7,   11,   11,    8,    7,

        5,    5,    8,   19,   19,   12,   12,   11,   12,   12,
       18,   20,   20,   29,   18,   56,   12,   40,   40,   29,
       48,   63,   56,   48,   63,    5,    5,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,   23,   28,   23,   23,   31,
       32,   34,   33,   33,   23,   23,   34,    6,    6,   28,
       33,   31,   36,   32,   34,   33,   35,   31,   37,   23,
       23,   36,   36,   44,   42,   42,   38,   39,   35,   42,
       37,   98,    6,    6,   22,   45,   22,   22,   35,   38,
       39,  366,   41,   22,   22,   41,   44,   45,   43,   46,

       98,   49,   22,   43,   41,   91,   43,   47,   22,   22,
       47,   41,   46,   49,   49,   51,   43,   51,   51,   43,
       59,   58,   58,   59,   47,   58,   22,   59,   91,   64,
       60,   60,   64,   68,   68,   65,   70,   60,   97,   87,
       70,   49,   60,   60,   97,   49,   87,   65,   65,   72,
       93,   72,   72,   79,   73,   73,   79,   79,   72,   76,
       76,   73,   73,   93,  108,   88,   76,   76,   88,  108,
       60,   94,   96,   72,   60,   65,   73,   73,  101,   65,
       92,   76,   76,   77,   96,   77,   77,   81,   94,   81,
       81,   99,   77,   77,   95,   95,   81,   81,   92,  100,

      101,  102,  100,  103,  106,  104,  107,   77,   77,  105,
       99,   81,   81,  105,  102,  109,  103,  104,  110,  111,
      111,  103,  106,  112,  107,  114,  113,  110,  115,  116,
      136,  117,  120,  109,  119,  118,  136,  115,  112,  113,
      117,  114,  119,  116,  118,  122,  121,  124,  117,  121,
      120,  125,  125,  149,  134,  193,  149,  122,  122,  124,
      124,  134,  137,  138,  138,  137,  139,  140,  140,  137,
      138,  142,  139,  193,  140,  138,  138,  142,  143,  140,
      140,  144,  142,  142,  143,  122,  152,  144,  150,  122,
      169,  124,  153,  153,  166,  157,  157,  186,  152,  152,

      150,  150,  157,  138,  166,  159,  169,  138,  159,  159,
      158,  140,  158,  158,  161,  161,  143,  157,  186,  158,
      165,  161,  161,  162,  162,  165,  144,  172,  150,  173,
      152,  170,  150,  180,  158,  171,  161,  161,  163,  163,
      171,  170,  176,  172,  174,  174,  173,  173,  175,  177,
      175,  178,  180,  176,  177,  181,  178,  179,  179,  182,
      181,  183,  184,  185,  188,  189,  182,  190,  185,  189,
      192,  184,  191,  194,  195,  196,  198,  198,  194,  192,
      183,  188,  199,  266,  196,  266,  190,  195,  191,  192,
      197,  201,  201,  207,  197,  209,  211,  212,  199,  207,

      213,  209,  211,  212,  216,  216,  213,  211,  211,  220,
      220,  221,  221,  222,  222,  223,  220,  226,  227,  230,
      232,  235,  231,  227,  233,  223,  226,  231,  236,  237,
      213,  220,  236,  238,  233,  235,  239,  230,  212,  232,
      241,  242,  243,  244,  244,  246,  248,  237,  245,  247,
      241,  238,  239,  245,  247,  249,  250,  253,  246,  250,
      243,  242,  251,  256,  248,  251,  252,  249,  254,  253,
      252,  257,  260,  267,  267,  254,  261,  269,  260,  256,
      257,  270,  261,  271,  272,  277,  276,  280,  271,  278,
      277,  270,  276,  282,  278,  283,  281,  285,  286,  269,

      287,  365,  272,  290,  285,  282,  260,  283,  287,  288,
      280,  292,  261,  281,  288,  290,  286,  293,  296,  295,
      295,  297,  300,  292,  296,  301,  295,  302,  303,  293,
      293,  295,  295,  297,  297,  305,  316,  301,  306,  306,
      311,  300,  316,  364,  305,  302,  303,  317,  312,  318,
      311,  312,  317,  319,  320,  320,  318,  323,  296,  363,
      322,  322,  325,  323,  324,  319,  319,  322,  323,  323,
      324,  329,  322,  322,  325,  325,  326,  326,  333,  334,
      335,  336,  334,  338,  341,  341,  336,  338,  358,  329,
      343,  333,  356,  345,  324,  355,  343,  348,  348,  345,

      346,  346,  352,  335,  345,  345,  351,  346,  353,  359,
      354,  351,  350,  353,  352,  359,  360,  360,  368,  368,
      369,  369,  349,  360,  368,  342,  369,  370,  370,  371,
      371,  373,  373,  339,  370,  337,  371,  332,  373,  374,
      374,  331,  330,  328,  327,  321,  374,  376,  376,  376,
      376,  376,  376,  376,  376,  377,  377,  377,  377,  377,
      377,  377,  377,  378,  378,  378,  378,  378,  378,  378,
      378,  379,  379,  379,  379,  379,  379,  379,  379,  380,
      380,  380,  380,  380,  380,  380,  380,  381,  381,  381,
      381,  382,  382,  382,  382,  383,  383,  315,  383,  383,

      383,  383,  383,  384,  384,  384,  314,  384,  384,  384,
      384,  385,  385,  385,  385,  386,  386,  386,  386,  386,
      386,  386,  386,  387,  387,  387,  387,  387,  387,  387,
      387,  388,  388,  313,  388,  388,  388,  388,  388,  389,
      389,  310,  389,  389,  389,  389,  389,  390,  390,  309,
      390,  390,  390,  390,  390,  391,  391,  392,  392,  392,
      392,  393,  393,  308,  393,  393,  393,  393,  393,  394,
      394,  307,  394,  394,  394,  394,  394,  395,  395,  395,
      395,  395,  395,  395,  395,  396,  396,  396,  396,  396,
      396,  396,  396,  397,  397,  304,  397,  397,  397,  397,

      397,  398,  398,  299,  398,  398,  398,  398,  398,  399,
      399,  298,  399,  399,  399,  399,  399,  400,  400,  294,
      400,  400,  400,  400,  400,  401,  401,  401,  401,  401,
      401,  401,  401,  402,  402,  291,  402,  402,  402,  402,
      402,  403,  403,  289,  403,  403,  403,  403,  403,  404,
      404,  404,  404,  404,  404,  404,  404,  405,  405,  284,
      405,  405,  405,  405,  405,  406,  406,  406,  279,  406,
      406,  275,  274,  273,  268,  265,  264,  263,  262,  259,
      258,  255,  240,  234,  229,  228,  225,  224,  218,  217,
      203,  202,  187,  168,  167,  155,  154,  146,  135,  132,

      130,  129,  127,  126,   90,   85,   67,   66,   62,   57,
       55,   50,   30,   27,   26,   25,   24,   15,   13,    3,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375
    } ;

static __IDL__state_type __IDL__last_accepting_state;
static char *__IDL__last_accepting_cpos;

extern int __IDL__flex_debug;
int __IDL__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define __IDL_more() __IDL_more_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *__IDL_text;
#line 1 "./lexer.l"
/***************************************************************************

    lexer.l (IDL lex scanner)

    Copyright (C) 1998, 1999 Andrew T. Veliath

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: lexer.l,v 1.83 2003/05/09 15:19:06 jody Exp $

***************************************************************************/
#line 25 "./lexer.l"
#include <assert.h>
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <string.h>
#include <glib.h>
#include "rename.h"
#include "util.h"
#include "parser.h"

#ifdef XP_MAC
#  include <unix.h>
#  define YY_NEVER_INTERACTIVE 1
#endif

/* Eliminate warning */
#define YY_NO_UNPUT 1

#define YY_INPUT(buf,result,the_max_size)	do {				\
	if (__IDL_inputcb == NULL) {						\
		if ((result = fread (buf, 1, the_max_size, __IDL_in)) == YY_NULL &&	\
		    ferror (__IDL_in))						\
			YY_FATAL_ERROR ("input in scanner failed");		\
	} else {								\
		union IDL_input_data data;					\
										\
		data.fill.buffer = buf;						\
		data.fill.max_size = the_max_size;				\
		result = (*__IDL_inputcb) (IDL_INPUT_REASON_FILL, &data,	\
					   __IDL_inputcb_user_data);		\
		if (result < 0)							\
			YY_FATAL_ERROR ("input callback returned failure");	\
	}									\
} while (0)

#define tokreturn(token)			do {	\
	__IDL_prev_token_line = __IDL_cur_token_line;	\
	__IDL_cur_token_line = __IDL_cur_line;		\
	return token;					\
} while (0)

#define SELECT_START				\
	/* Parser driven start conditions */	\
	if (__IDL_flagsi & IDLFP_PROPERTIES)	\
		BEGIN (PROP);			\
	else if (__IDL_flagsi & IDLFP_NATIVE)	\
		BEGIN (NATIVE);			\
	/* Global syntax start conditions */	\
	else if (__IDL_flags & IDLF_XPIDL)	\
		BEGIN (XP);			\
	else if (__IDL_flags & IDLF_CODEFRAGS)	\
		BEGIN (CFRG);

#define SELECT_RESTART				\
	SELECT_START				\
	else					\
		BEGIN (INITIAL);

static int		count_nl			(const char *s);

static void IDL_parse_cpp_status(char *mytext) {
	gint   line;

	line = atoi (mytext);

	while (g_ascii_isdigit (*mytext))
		mytext++;

	if (g_ascii_isspace (*mytext)) {
		mytext++;

		if (mytext [0] == '"') {
			gchar *p = ++mytext;

			while (*p && *p != '"') p++;

			*p = '\0';
		}

		if (mytext [0] ==  '<' &&
		    (!strcmp (mytext, "<builtin>")  ||
		     !strcmp (mytext, "<built-in>") ||
		     !strcmp (mytext, "<stdin>")    ||
		     !strcmp (mytext, "<command-line>") ||
		     !strcmp (mytext, "<command line>")))

			__IDL_lval.tree = IDL_file_set ("", line);
		else {
			gchar *filename = g_strdup (mytext);
#ifdef G_OS_WIN32
			/*
			 * On Windows when using MSVC, the file name
			 * output by cl.exe may have "\\" as the path
			 * separator. We need to strip the extra '\'
			 * so we can compare to our internal file
			 * name.
			 */
			gchar *dst, *src;
			for (dst = filename, src = mytext;
			     *src != '\0'; src++, dst++) {
			  if (*src == '\\' && *(src + 1) == '\\') {
			    src++;
			  }
			  *dst = *src;
			}
			*dst = '\0';
#endif

			__IDL_lval.tree = IDL_file_set (filename, line);

			g_free (filename);
		}
	}
	else
		__IDL_lval.tree = IDL_file_set ("", line);
}


#ifdef YYDEBUG
extern int				__IDL_debug;
#endif
int					__IDL_prev_token_line;
int					__IDL_cur_token_line;
static int				warn_underscores;
static char *				codefrag_desc;
static GSList *				codefrag_list;
static GSList *				codefrag_list_tail;
#line 958 "<stdout>"

#line 960 "<stdout>"

#define INITIAL 0
#define XP 1
#define PROP 2
#define NATIVE 3
#define CFRG 4
#define CFRGX 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int __IDL__init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int __IDL_lex_destroy ( void );

int __IDL_get_debug ( void );

void __IDL_set_debug ( int debug_flag  );

YY_EXTRA_TYPE __IDL_get_extra ( void );

void __IDL_set_extra ( YY_EXTRA_TYPE user_defined  );

FILE *__IDL_get_in ( void );

void __IDL_set_in  ( FILE * _in_str  );

FILE *__IDL_get_out ( void );

void __IDL_set_out  ( FILE * _out_str  );

			int __IDL_get_leng ( void );

char *__IDL_get_text ( void );

int __IDL_get_lineno ( void );

void __IDL_set_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int __IDL_wrap ( void );
#else
extern int __IDL_wrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void __IDL_unput ( int c, char *buf_ptr  );
    
#endif

#ifndef __IDL_text_ptr
static void __IDL__flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int __IDL__flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int __IDL_input ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( __IDL_text, (size_t) __IDL_leng, 1, __IDL_out )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->__IDL__is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( __IDL_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( __IDL_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (__IDL__size_t) max_size, __IDL_in)) == 0 && ferror(__IDL_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(__IDL_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "__IDL_terminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef __IDL_terminate
#define __IDL_terminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) __IDL__fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int __IDL_lex (void);

#define YY_DECL int __IDL_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after __IDL_text and __IDL_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( __IDL_leng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->__IDL__at_bol = \
				(__IDL_text[__IDL_leng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	__IDL__state_type __IDL__current_state;
	char *__IDL__cp, *__IDL__bp;
	int __IDL__act;
    
	if ( !(__IDL__init) )
		{
		(__IDL__init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (__IDL__start) )
			(__IDL__start) = 1;	/* first start state */

		if ( ! __IDL_in )
			__IDL_in = stdin;

		if ( ! __IDL_out )
			__IDL_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			__IDL_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				__IDL__create_buffer( __IDL_in, YY_BUF_SIZE );
		}

		__IDL__load_buffer_state(  );
		}

	{
#line 186 "./lexer.l"


#line 189 "./lexer.l"
	SELECT_START;

#line 1191 "<stdout>"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		__IDL__cp = (__IDL__c_buf_p);

		/* Support of __IDL_text. */
		*__IDL__cp = (__IDL__hold_char);

		/* __IDL__bp points to the position in __IDL__ch_buf of the start of
		 * the current run.
		 */
		__IDL__bp = __IDL__cp;

		__IDL__current_state = (__IDL__start);
		__IDL__current_state += YY_AT_BOL();
__IDL__match:
		do
			{
			YY_CHAR __IDL__c = __IDL__ec[YY_SC_TO_UI(*__IDL__cp)] ;
			if ( __IDL__accept[__IDL__current_state] )
				{
				(__IDL__last_accepting_state) = __IDL__current_state;
				(__IDL__last_accepting_cpos) = __IDL__cp;
				}
			while ( __IDL__chk[__IDL__base[__IDL__current_state] + __IDL__c] != __IDL__current_state )
				{
				__IDL__current_state = (int) __IDL__def[__IDL__current_state];
				if ( __IDL__current_state >= 376 )
					__IDL__c = __IDL__meta[__IDL__c];
				}
			__IDL__current_state = __IDL__nxt[__IDL__base[__IDL__current_state] + __IDL__c];
			++__IDL__cp;
			}
		while ( __IDL__base[__IDL__current_state] != 1021 );

__IDL__find_action:
		__IDL__act = __IDL__accept[__IDL__current_state];
		if ( __IDL__act == 0 )
			{ /* have to back up */
			__IDL__cp = (__IDL__last_accepting_cpos);
			__IDL__current_state = (__IDL__last_accepting_state);
			__IDL__act = __IDL__accept[__IDL__current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( __IDL__act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*__IDL__cp = (__IDL__hold_char);
			__IDL__cp = (__IDL__last_accepting_cpos);
			__IDL__current_state = (__IDL__last_accepting_state);
			goto __IDL__find_action;

case 1:
YY_RULE_SETUP
#line 191 "./lexer.l"
{
	char *s = __IDL_text + 2;

	while (g_ascii_isspace (*s)) ++s;
	codefrag_desc = g_strdup (s);
	codefrag_list = codefrag_list_tail = NULL;

	if (!(__IDL_flags & IDLF_XPIDL || __IDL_flags & IDLF_CODEFRAGS))
		__IDL_error ("Code fragment syntax not enabled");
	else
		BEGIN (CFRGX);
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 203 "./lexer.l"
{
	__IDL_lval.tree = IDL_codefrag_new (codefrag_desc, codefrag_list);
	tokreturn (TOK_CODEFRAG);
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 207 "./lexer.l"
{
	char *s;
	GSList *slist;

	s = g_strdup (__IDL_text);
	slist = g_slist_alloc ();
	slist->data = s;

	if (codefrag_list == NULL) {
		codefrag_list = slist;
		codefrag_list_tail = slist;
	} else {
		codefrag_list_tail->next = slist;
		codefrag_list_tail = slist;
	}
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 223 "./lexer.l"
{
	int n;
	char *p = __IDL_text;
	char *s, *t;

	while (g_ascii_isspace (*p) || *p == '#') ++p;
	s = p;
	sscanf (p, "%*6s%n", &n); s += n;
	while (g_ascii_isspace (*s)) ++s;

	t = s + strlen(s) - 1;
	while(g_ascii_isspace(*t) && t > s) *(t--) = '\0'; /* Chomp trailing spaces */

	__IDL_do_pragma (s);
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 238 "./lexer.l"
{
	gchar *mytext = __IDL_text;

	while (g_ascii_isspace (*mytext))
		mytext++;

	g_assert (mytext [0] == '#' && mytext [1] == ' ');

	mytext += 2;
	IDL_parse_cpp_status(mytext);
	if (__IDL_lval.tree)
	 	tokreturn (TOK_SRCFILE);
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 251 "./lexer.l"
{
	gchar *mytext = __IDL_text;

	while (g_ascii_isspace (*mytext))
		mytext++;

	g_assert (mytext [0] == '#' &&
		  mytext [1] == 'l' &&
		  mytext [2] == 'i' &&
		  mytext [3] == 'n' &&
		  mytext [4] == 'e' &&
		  g_ascii_isspace(mytext [5]));

	mytext += 6;
	IDL_parse_cpp_status(mytext);
	if (__IDL_lval.tree)
	 	tokreturn (TOK_SRCFILE);
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 269 "./lexer.l"
;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 270 "./lexer.l"
;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 271 "./lexer.l"
{
	__IDL_lval.integer = 0;
	sscanf (__IDL_text, "%" IDL_LL "o", &__IDL_lval.integer);
	tokreturn (TOK_INTEGER);
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 276 "./lexer.l"
{
	__IDL_lval.integer = 0;
	sscanf (__IDL_text, "%" IDL_LL "u", &__IDL_lval.integer);
	tokreturn (TOK_INTEGER);
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 281 "./lexer.l"
{
	__IDL_lval.integer = 0;
	sscanf (__IDL_text + 2, "%" IDL_LL "x", &__IDL_lval.integer);
	tokreturn (TOK_INTEGER);
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 286 "./lexer.l"
{
	__IDL_lval.str = g_strdup (__IDL_text);
	tokreturn (TOK_FIXEDP);
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 290 "./lexer.l"
{
	__IDL_lval.floatp = atof (__IDL_text);
	tokreturn (TOK_FLOATP);
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 294 "./lexer.l"
tokreturn (TOK_FALSE);
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 295 "./lexer.l"
tokreturn (TOK_TRUE);
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 296 "./lexer.l"
tokreturn (TOK_ANY);
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 297 "./lexer.l"
tokreturn (TOK_ATTRIBUTE);
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 298 "./lexer.l"
tokreturn (TOK_BOOLEAN);
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 299 "./lexer.l"
tokreturn (TOK_CASE);
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 300 "./lexer.l"
tokreturn (TOK_CHAR);
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 301 "./lexer.l"
tokreturn (TOK_CONST);
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 302 "./lexer.l"
tokreturn (TOK_CONTEXT);
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 303 "./lexer.l"
tokreturn (TOK_DEFAULT);
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 304 "./lexer.l"
tokreturn (TOK_DOUBLE);
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 305 "./lexer.l"
tokreturn (TOK_ENUM);
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 306 "./lexer.l"
tokreturn (TOK_EXCEPTION);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 307 "./lexer.l"
tokreturn (TOK_FIXED);
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 308 "./lexer.l"
tokreturn (TOK_FLOAT);
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 309 "./lexer.l"
tokreturn (TOK_IN);
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 310 "./lexer.l"
tokreturn (TOK_INOUT);
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 311 "./lexer.l"
tokreturn (TOK_INTERFACE);
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 312 "./lexer.l"
tokreturn (TOK_LONG);
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 313 "./lexer.l"
tokreturn (TOK_MODULE);
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 314 "./lexer.l"
tokreturn (TOK_NATIVE);
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 315 "./lexer.l"
tokreturn (TOK_OCTET);
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 316 "./lexer.l"
tokreturn (TOK_ONEWAY);
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 317 "./lexer.l"
tokreturn (TOK_OUT);
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 318 "./lexer.l"
tokreturn (TOK_RAISES);
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 319 "./lexer.l"
tokreturn (TOK_READONLY);
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 320 "./lexer.l"
tokreturn (TOK_SEQUENCE);
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 321 "./lexer.l"
tokreturn (TOK_SHORT);
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 322 "./lexer.l"
tokreturn (TOK_STRING);
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 323 "./lexer.l"
tokreturn (TOK_STRUCT);
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 324 "./lexer.l"
tokreturn (TOK_SWITCH);
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 325 "./lexer.l"
tokreturn (TOK_TYPEDEF);
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 326 "./lexer.l"
tokreturn (TOK_UNION);
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 327 "./lexer.l"
tokreturn (TOK_UNSIGNED);
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 328 "./lexer.l"
tokreturn (TOK_VARARGS);
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 329 "./lexer.l"
tokreturn (TOK_VOID);
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 330 "./lexer.l"
tokreturn (TOK_WCHAR);
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 331 "./lexer.l"
tokreturn (TOK_WSTRING);
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 332 "./lexer.l"
tokreturn (TOK_OP_SCOPE);
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 333 "./lexer.l"
tokreturn (TOK_OP_SHR);
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 334 "./lexer.l"
tokreturn (TOK_OP_SHL);
	YY_BREAK
case 55:
/* rule 55 can match eol */
YY_RULE_SETUP
#line 335 "./lexer.l"
{
	char *s = g_strdup (__IDL_text);

	/* Get the parenthesized expression (ignoring whitespace) */
	sscanf (__IDL_text, "__declspec %*[(] %[A-Za-z_] %*[)]", s);
	__IDL_lval.str = s;
	__IDL_cur_line += count_nl (__IDL_text);
	tokreturn (TOK_DECLSPEC);
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 344 "./lexer.l"
{
#if 0
	if ((__IDL_flags & IDLF_TYPECODES) && strcmp (__IDL_text, "TypeCode") == 0)
		tokreturn (TOK_TYPECODE);
#endif
	if (__IDL_typecodes_as_tok>0 && strcmp (__IDL_text, "TypeCode") == 0)
		tokreturn (TOK_TYPECODE);
	if ( (__IDL_pidl <= 0) && strcmp(__IDL_text, "Object")==0 )
		tokreturn (TOK_OBJECT);
	__IDL_lval.str = g_strdup (__IDL_text);
	tokreturn (TOK_IDENT);
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 356 "./lexer.l"
{
	__IDL_lval.str = g_strdup (&__IDL_text[1]);
	tokreturn (TOK_IDENT);
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 360 "./lexer.l"
{
	if (!warn_underscores) {
		__IDL_warningv (IDL_WARNING2,
			   "`%s' underscores within identifiers are discouraged for use "
			   "with C-language IDL mappings", __IDL_text);
		warn_underscores = 1;
	}
	__IDL_lval.str = g_strdup (__IDL_text);
	tokreturn (TOK_IDENT);
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 370 "./lexer.l"
{
	__IDL_flagsi &= ~IDLFP_PROPERTIES;
	SELECT_RESTART;
	tokreturn (__IDL_text[0]);
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 375 "./lexer.l"
{
	__IDL_lval.str = g_strdup (__IDL_text);
	tokreturn (TOK_PROP_KEY);
}
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
#line 379 "./lexer.l"
{
	__IDL_lval.str = g_strdup (__IDL_text + 1);
	__IDL_lval.str[strlen (__IDL_lval.str) - 1] = 0;
	tokreturn (TOK_PROP_VALUE);
}
	YY_BREAK
case 62:
/* rule 62 can match eol */
YY_RULE_SETUP
#line 384 "./lexer.l"
{
	__IDL_flagsi &= ~IDLFP_NATIVE;
	__IDL_lval.str = g_strdup (__IDL_text);
	__IDL_lval.str[strlen (__IDL_lval.str) - 1] = 0;
	tokreturn (TOK_NATIVE_TYPE);
}
	YY_BREAK
case 63:
/* rule 63 can match eol */
YY_RULE_SETUP
#line 390 "./lexer.l"
{
	__IDL_lval.str = g_strdup (__IDL_text + 1);
	__IDL_lval.str[strlen (__IDL_text) - 2] = 0;
	tokreturn (TOK_SQSTRING);
}
	YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
#line 395 "./lexer.l"
{
	__IDL_lval.str = g_strdup (__IDL_text + 1);
	__IDL_lval.str[strlen (__IDL_text) - 2] = 0;
	tokreturn (TOK_DQSTRING);
}
	YY_BREAK
case 65:
/* rule 65 can match eol */
YY_RULE_SETUP
#line 400 "./lexer.l"
++__IDL_cur_line;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 401 "./lexer.l"
;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 402 "./lexer.l"
{
	int c;

	while (1) {
		while ((c = input ()) != '*' && c != EOF)
			if (c == '\n') ++__IDL_cur_line;
		if (c == '*') {
			while ((c = input ()) == '*') ;
			if (c == '/') break;
		}
		if (c == '\n') ++__IDL_cur_line;
		if (c == EOF) {
			__IDL_warning (IDL_WARNING1, "End of file in comment");
			break;
		}
	}
}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 419 "./lexer.l"
tokreturn (__IDL_text[0]);
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 421 "./lexer.l"
ECHO;
	YY_BREAK
#line 1761 "<stdout>"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(XP):
case YY_STATE_EOF(PROP):
case YY_STATE_EOF(NATIVE):
case YY_STATE_EOF(CFRG):
case YY_STATE_EOF(CFRGX):
	__IDL_terminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int __IDL__amount_of_matched_text = (int) (__IDL__cp - (__IDL_text_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*__IDL__cp = (__IDL__hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->__IDL__buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed __IDL_in at a new source and called
			 * __IDL_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(__IDL__n_chars) = YY_CURRENT_BUFFER_LVALUE->__IDL__n_chars;
			YY_CURRENT_BUFFER_LVALUE->__IDL__input_file = __IDL_in;
			YY_CURRENT_BUFFER_LVALUE->__IDL__buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for __IDL__c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since __IDL__c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (__IDL__c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[(__IDL__n_chars)] )
			{ /* This was really a NUL. */
			__IDL__state_type __IDL__next_state;

			(__IDL__c_buf_p) = (__IDL_text_ptr) + __IDL__amount_of_matched_text;

			__IDL__current_state = __IDL__get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * __IDL__get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			__IDL__next_state = __IDL__try_NUL_trans( __IDL__current_state );

			__IDL__bp = (__IDL_text_ptr) + YY_MORE_ADJ;

			if ( __IDL__next_state )
				{
				/* Consume the NUL. */
				__IDL__cp = ++(__IDL__c_buf_p);
				__IDL__current_state = __IDL__next_state;
				goto __IDL__match;
				}

			else
				{
				__IDL__cp = (__IDL__c_buf_p);
				goto __IDL__find_action;
				}
			}

		else switch ( __IDL__get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(__IDL__did_buffer_switch_on_eof) = 0;

				if ( __IDL_wrap(  ) )
					{
					/* Note: because we've taken care in
					 * __IDL__get_next_buffer() to have set up
					 * __IDL_text, we can now set up
					 * __IDL__c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(__IDL__c_buf_p) = (__IDL_text_ptr) + YY_MORE_ADJ;

					__IDL__act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (__IDL__did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(__IDL__c_buf_p) =
					(__IDL_text_ptr) + __IDL__amount_of_matched_text;

				__IDL__current_state = __IDL__get_previous_state(  );

				__IDL__cp = (__IDL__c_buf_p);
				__IDL__bp = (__IDL_text_ptr) + YY_MORE_ADJ;
				goto __IDL__match;

			case EOB_ACT_LAST_MATCH:
				(__IDL__c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[(__IDL__n_chars)];

				__IDL__current_state = __IDL__get_previous_state(  );

				__IDL__cp = (__IDL__c_buf_p);
				__IDL__bp = (__IDL_text_ptr) + YY_MORE_ADJ;
				goto __IDL__find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of __IDL_lex */

/* __IDL__get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int __IDL__get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf;
	char *source = (__IDL_text_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (__IDL__c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[(__IDL__n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->__IDL__fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (__IDL__c_buf_p) - (__IDL_text_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((__IDL__c_buf_p) - (__IDL_text_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->__IDL__buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->__IDL__n_chars = (__IDL__n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->__IDL__buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int __IDL__c_buf_p_offset =
				(int) ((__IDL__c_buf_p) - b->__IDL__ch_buf);

			if ( b->__IDL__is_our_buffer )
				{
				int new_size = b->__IDL__buf_size * 2;

				if ( new_size <= 0 )
					b->__IDL__buf_size += b->__IDL__buf_size / 8;
				else
					b->__IDL__buf_size *= 2;

				b->__IDL__ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					__IDL_realloc( (void *) b->__IDL__ch_buf,
							 (__IDL__size_t) (b->__IDL__buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->__IDL__ch_buf = NULL;

			if ( ! b->__IDL__ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(__IDL__c_buf_p) = &b->__IDL__ch_buf[__IDL__c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->__IDL__buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[number_to_move]),
			(__IDL__n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->__IDL__n_chars = (__IDL__n_chars);
		}

	if ( (__IDL__n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			__IDL_restart( __IDL_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->__IDL__buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((__IDL__n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->__IDL__buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (__IDL__n_chars) + number_to_move + ((__IDL__n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf = (char *) __IDL_realloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf, (__IDL__size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in __IDL__get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->__IDL__buf_size = (int) (new_size - 2);
	}

	(__IDL__n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[(__IDL__n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[(__IDL__n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(__IDL_text_ptr) = &YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[0];

	return ret_val;
}

/* __IDL__get_previous_state - get the state just before the EOB char was reached */

    static __IDL__state_type __IDL__get_previous_state (void)
{
	__IDL__state_type __IDL__current_state;
	char *__IDL__cp;
    
	__IDL__current_state = (__IDL__start);
	__IDL__current_state += YY_AT_BOL();

	for ( __IDL__cp = (__IDL_text_ptr) + YY_MORE_ADJ; __IDL__cp < (__IDL__c_buf_p); ++__IDL__cp )
		{
		YY_CHAR __IDL__c = (*__IDL__cp ? __IDL__ec[YY_SC_TO_UI(*__IDL__cp)] : 1);
		if ( __IDL__accept[__IDL__current_state] )
			{
			(__IDL__last_accepting_state) = __IDL__current_state;
			(__IDL__last_accepting_cpos) = __IDL__cp;
			}
		while ( __IDL__chk[__IDL__base[__IDL__current_state] + __IDL__c] != __IDL__current_state )
			{
			__IDL__current_state = (int) __IDL__def[__IDL__current_state];
			if ( __IDL__current_state >= 376 )
				__IDL__c = __IDL__meta[__IDL__c];
			}
		__IDL__current_state = __IDL__nxt[__IDL__base[__IDL__current_state] + __IDL__c];
		}

	return __IDL__current_state;
}

/* __IDL__try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = __IDL__try_NUL_trans( current_state );
 */
    static __IDL__state_type __IDL__try_NUL_trans  (__IDL__state_type __IDL__current_state )
{
	int __IDL__is_jam;
    	char *__IDL__cp = (__IDL__c_buf_p);

	YY_CHAR __IDL__c = 1;
	if ( __IDL__accept[__IDL__current_state] )
		{
		(__IDL__last_accepting_state) = __IDL__current_state;
		(__IDL__last_accepting_cpos) = __IDL__cp;
		}
	while ( __IDL__chk[__IDL__base[__IDL__current_state] + __IDL__c] != __IDL__current_state )
		{
		__IDL__current_state = (int) __IDL__def[__IDL__current_state];
		if ( __IDL__current_state >= 376 )
			__IDL__c = __IDL__meta[__IDL__c];
		}
	__IDL__current_state = __IDL__nxt[__IDL__base[__IDL__current_state] + __IDL__c];
	__IDL__is_jam = (__IDL__current_state == 375);

		return __IDL__is_jam ? 0 : __IDL__current_state;
}

#ifndef YY_NO_UNPUT

    static void __IDL_unput (int c, char * __IDL__bp )
{
	char *__IDL__cp;
    
    __IDL__cp = (__IDL__c_buf_p);

	/* undo effects of setting up __IDL_text */
	*__IDL__cp = (__IDL__hold_char);

	if ( __IDL__cp < YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (__IDL__n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[
					YY_CURRENT_BUFFER_LVALUE->__IDL__buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf )
			*--dest = *--source;

		__IDL__cp += (int) (dest - source);
		__IDL__bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->__IDL__n_chars =
			(__IDL__n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->__IDL__buf_size;

		if ( __IDL__cp < YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--__IDL__cp = (char) c;

	(__IDL_text_ptr) = __IDL__bp;
	(__IDL__hold_char) = *__IDL__cp;
	(__IDL__c_buf_p) = __IDL__cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int __IDL_input (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(__IDL__c_buf_p) = (__IDL__hold_char);

	if ( *(__IDL__c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* __IDL__c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (__IDL__c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->__IDL__ch_buf[(__IDL__n_chars)] )
			/* This was really a NUL. */
			*(__IDL__c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((__IDL__c_buf_p) - (__IDL_text_ptr));
			++(__IDL__c_buf_p);

			switch ( __IDL__get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because __IDL__g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					__IDL_restart( __IDL_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( __IDL_wrap(  ) )
						return 0;

					if ( ! (__IDL__did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return __IDL_input();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(__IDL__c_buf_p) = (__IDL_text_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (__IDL__c_buf_p);	/* cast for 8-bit char's */
	*(__IDL__c_buf_p) = '\0';	/* preserve __IDL_text */
	(__IDL__hold_char) = *++(__IDL__c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->__IDL__at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void __IDL_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        __IDL_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            __IDL__create_buffer( __IDL_in, YY_BUF_SIZE );
	}

	__IDL__init_buffer( YY_CURRENT_BUFFER, input_file );
	__IDL__load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void __IDL__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		__IDL_pop_buffer_state();
	 *		__IDL_push_buffer_state(new_buffer);
     */
	__IDL_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(__IDL__c_buf_p) = (__IDL__hold_char);
		YY_CURRENT_BUFFER_LVALUE->__IDL__buf_pos = (__IDL__c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->__IDL__n_chars = (__IDL__n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	__IDL__load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (__IDL_wrap()) processing, but the only time this flag
	 * is looked at is after __IDL_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(__IDL__did_buffer_switch_on_eof) = 1;
}

static void __IDL__load_buffer_state  (void)
{
    	(__IDL__n_chars) = YY_CURRENT_BUFFER_LVALUE->__IDL__n_chars;
	(__IDL_text_ptr) = (__IDL__c_buf_p) = YY_CURRENT_BUFFER_LVALUE->__IDL__buf_pos;
	__IDL_in = YY_CURRENT_BUFFER_LVALUE->__IDL__input_file;
	(__IDL__hold_char) = *(__IDL__c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE __IDL__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) __IDL_alloc( sizeof( struct __IDL__buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in __IDL__create_buffer()" );

	b->__IDL__buf_size = size;

	/* __IDL__ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->__IDL__ch_buf = (char *) __IDL_alloc( (__IDL__size_t) (b->__IDL__buf_size + 2)  );
	if ( ! b->__IDL__ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in __IDL__create_buffer()" );

	b->__IDL__is_our_buffer = 1;

	__IDL__init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with __IDL__create_buffer()
 * 
 */
    void __IDL__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->__IDL__is_our_buffer )
		__IDL_free( (void *) b->__IDL__ch_buf  );

	__IDL_free( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a __IDL_restart() or at EOF.
 */
    static void __IDL__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	__IDL__flush_buffer( b );

	b->__IDL__input_file = file;
	b->__IDL__fill_buffer = 1;

    /* If b is the current buffer, then __IDL__init_buffer was _probably_
     * called from __IDL_restart() or through __IDL__get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->__IDL__bs_lineno = 1;
        b->__IDL__bs_column = 0;
    }

        b->__IDL__is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void __IDL__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->__IDL__n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->__IDL__ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->__IDL__ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->__IDL__buf_pos = &b->__IDL__ch_buf[0];

	b->__IDL__at_bol = 1;
	b->__IDL__buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		__IDL__load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void __IDL_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	__IDL_ensure_buffer_stack();

	/* This block is copied from __IDL__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(__IDL__c_buf_p) = (__IDL__hold_char);
		YY_CURRENT_BUFFER_LVALUE->__IDL__buf_pos = (__IDL__c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->__IDL__n_chars = (__IDL__n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(__IDL__buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from __IDL__switch_to_buffer. */
	__IDL__load_buffer_state(  );
	(__IDL__did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void __IDL_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	__IDL__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((__IDL__buffer_stack_top) > 0)
		--(__IDL__buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		__IDL__load_buffer_state(  );
		(__IDL__did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void __IDL_ensure_buffer_stack (void)
{
	__IDL__size_t num_to_alloc;
    
	if (!(__IDL__buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(__IDL__buffer_stack) = (struct __IDL__buffer_state**)__IDL_alloc
								(num_to_alloc * sizeof(struct __IDL__buffer_state*)
								);
		if ( ! (__IDL__buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in __IDL_ensure_buffer_stack()" );

		memset((__IDL__buffer_stack), 0, num_to_alloc * sizeof(struct __IDL__buffer_state*));

		(__IDL__buffer_stack_max) = num_to_alloc;
		(__IDL__buffer_stack_top) = 0;
		return;
	}

	if ((__IDL__buffer_stack_top) >= ((__IDL__buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		__IDL__size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (__IDL__buffer_stack_max) + grow_size;
		(__IDL__buffer_stack) = (struct __IDL__buffer_state**)__IDL_realloc
								((__IDL__buffer_stack),
								num_to_alloc * sizeof(struct __IDL__buffer_state*)
								);
		if ( ! (__IDL__buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in __IDL_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((__IDL__buffer_stack) + (__IDL__buffer_stack_max), 0, grow_size * sizeof(struct __IDL__buffer_state*));
		(__IDL__buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE __IDL__scan_buffer  (char * base, __IDL__size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) __IDL_alloc( sizeof( struct __IDL__buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in __IDL__scan_buffer()" );

	b->__IDL__buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->__IDL__buf_pos = b->__IDL__ch_buf = base;
	b->__IDL__is_our_buffer = 0;
	b->__IDL__input_file = NULL;
	b->__IDL__n_chars = b->__IDL__buf_size;
	b->__IDL__is_interactive = 0;
	b->__IDL__at_bol = 1;
	b->__IDL__fill_buffer = 0;
	b->__IDL__buffer_status = YY_BUFFER_NEW;

	__IDL__switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to __IDL_lex() will
 * scan from a @e copy of @a str.
 * @param __IDL_str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       __IDL__scan_bytes() instead.
 */
YY_BUFFER_STATE __IDL__scan_string (const char * __IDL_str )
{
    
	return __IDL__scan_bytes( __IDL_str, (int) strlen(__IDL_str) );
}

/** Setup the input buffer state to scan the given bytes. The next call to __IDL_lex() will
 * scan from a @e copy of @a bytes.
 * @param __IDL_bytes the byte buffer to scan
 * @param ___IDL_bytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE __IDL__scan_bytes  (const char * __IDL_bytes, int  ___IDL_bytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	__IDL__size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (__IDL__size_t) (___IDL_bytes_len + 2);
	buf = (char *) __IDL_alloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in __IDL__scan_bytes()" );

	for ( i = 0; i < ___IDL_bytes_len; ++i )
		buf[i] = __IDL_bytes[i];

	buf[___IDL_bytes_len] = buf[___IDL_bytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = __IDL__scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in __IDL__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->__IDL__is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void __IDL_noreturn __IDL__fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine __IDL_less() so it works in section 3 code. */

#undef __IDL_less
#define __IDL_less(n) \
	do \
		{ \
		/* Undo effects of setting up __IDL_text. */ \
        int __IDL_less_macro_arg = (n); \
        YY_LESS_LINENO(__IDL_less_macro_arg);\
		__IDL_text[__IDL_leng] = (__IDL__hold_char); \
		(__IDL__c_buf_p) = __IDL_text + __IDL_less_macro_arg; \
		(__IDL__hold_char) = *(__IDL__c_buf_p); \
		*(__IDL__c_buf_p) = '\0'; \
		__IDL_leng = __IDL_less_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int __IDL_get_lineno  (void)
{
    
    return __IDL_lineno;
}

/** Get the input stream.
 * 
 */
FILE *__IDL_get_in  (void)
{
        return __IDL_in;
}

/** Get the output stream.
 * 
 */
FILE *__IDL_get_out  (void)
{
        return __IDL_out;
}

/** Get the length of the current token.
 * 
 */
int __IDL_get_leng  (void)
{
        return __IDL_leng;
}

/** Get the current token.
 * 
 */

char *__IDL_get_text  (void)
{
        return __IDL_text;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void __IDL_set_lineno (int  _line_number )
{
    
    __IDL_lineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see __IDL__switch_to_buffer
 */
void __IDL_set_in (FILE *  _in_str )
{
        __IDL_in = _in_str ;
}

void __IDL_set_out (FILE *  _out_str )
{
        __IDL_out = _out_str ;
}

int __IDL_get_debug  (void)
{
        return __IDL__flex_debug;
}

void __IDL_set_debug (int  _bdebug )
{
        __IDL__flex_debug = _bdebug ;
}

static int __IDL__init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from __IDL_lex_destroy(), so don't allocate here.
     */

    (__IDL__buffer_stack) = NULL;
    (__IDL__buffer_stack_top) = 0;
    (__IDL__buffer_stack_max) = 0;
    (__IDL__c_buf_p) = NULL;
    (__IDL__init) = 0;
    (__IDL__start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    __IDL_in = stdin;
    __IDL_out = stdout;
#else
    __IDL_in = NULL;
    __IDL_out = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * __IDL_lex_init()
     */
    return 0;
}

/* __IDL_lex_destroy is for both reentrant and non-reentrant scanners. */
int __IDL_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		__IDL__delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		__IDL_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	__IDL_free((__IDL__buffer_stack) );
	(__IDL__buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * __IDL_lex() is called, initialization will occur. */
    __IDL__init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef __IDL_text_ptr
static void __IDL__flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int __IDL__flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *__IDL_alloc (__IDL__size_t  size )
{
			return malloc(size);
}

void *__IDL_realloc  (void * ptr, __IDL__size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void __IDL_free (void * ptr )
{
			free( (char *) ptr );	/* see __IDL_realloc() for (char *) cast */
}

#define YYTABLES_NAME "__IDL_tables"

#line 421 "./lexer.l"


void __IDL_lex_init (void)
{
	__IDL_inputcb = NULL;
	__IDL_cur_line = 1;
	__IDL_cur_token_line = 0;
	__IDL_prev_token_line = 0;
	__IDL_cur_filename = NULL;
	__IDL_cur_fileinfo = NULL;
	warn_underscores = 0;
}

void __IDL_lex_cleanup (void)
{
	__IDL_cur_filename = NULL;
#ifdef YY_NEW_FILE
	YY_NEW_FILE; /* obsolete with newer versions of flex */
#endif
}

int __IDL_wrap (void)
{
	return 1;
}

static int count_nl (const char *s)
{
	int i;

	for (i = 0;
	     (s = strchr (s, '\n')) != NULL;
	     ++s, ++i) ;

	return i;
}

/*
 * Local variables:
 * mode: C
 * c-basic-offset: 8
 * tab-width: 8
 * indent-tabs-mode: t
 * End:
 */

